pub(crate) const fn spell_modifier_owner(source: ActorId) -> Option<ActorId>Expand description
Resolves the player that owns spell modifiers for a casting actor. Trinity resolves player casts to that player and pet or totem casts to the owning player. Unowned external and enemy actors have no spell-mod owner.